
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.98'
version = '1.2.98'
full_version = '1.2.98'
git_revision = '5be8a01dfbb6806de10d8f7b9509e82f8cc00f1a'
release = True

if not release:
    version = full_version
    short_version += ".dev"
